#
# spec file for package libgnome
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libgnome
Version:        2.32.2+20170910.8487c2b4
Release:        2.1
Summary:        The GNOME 2.x Desktop Base Libraries
License:        LGPL-2.1-or-later
Group:          Development/Libraries/GNOME
URL:            http://www.gnome.org/
# Source based on tar_scm _service
Source:         %{name}-%{version}.tar.xz
#Source:         http://ftp.gnome.org/pub/GNOME/sources/%%{name}/2.32/%%{name}-%%{version}.tar.bz2
Source99:       baselibs.conf
# PATCH-FIX-OPENSUSE libgnome-sounds-default.diff -- Set default sounds for events
Patch4:         libgnome-sounds-default.patch
# PATCH-FIX-UPSTREAM libgnome-uninitialized-vars.patch bgo543570
Patch6:         libgnome-uninitialized-vars.patch
# PATCH-FIX-UPSTREAM libgnome-va_list-empty.patch bgo543570 -- This fixes the same as libgnome-uninitialized-vars.patch, so both can go away when upstream accepts patc
Patch8:         libgnome-va_list-empty.patch
# PATCH-NEEDS-REBASE libgnome-help-bundles.patch  -- was: PATCH-FIX-OPENSUSE
Patch9:         libgnome-help-bundles.patch
BuildRequires:  fdupes
BuildRequires:  gconf2-devel
BuildRequires:  gnome-common
BuildRequires:  gnome-vfs2-devel
BuildRequires:  gtk-doc
BuildRequires:  gtk2-devel
BuildRequires:  intltool
BuildRequires:  libbonobo-devel
BuildRequires:  libcanberra-devel
BuildRequires:  pkgconfig
BuildRequires:  translation-update-upstream
Recommends:     %{name}-lang = %{version}
#
# A bunch of legacy gnome apps relies more or less on yelp for a working help system (it can be reconfigured). Thus we recommend yelp from here, as low in the stack as it makes sense.
Recommends:     yelp
%{gconf_schemas_prereq}

%description
This package contains the basic libraries for the GNOME 2.x Desktop
platform. GNOME has no specific window manager. You are totally free in
your choice. Many GNOME users like Sawfish, Enlightenment, or IceWM as
a window manager for GNOME (see those packages).

%package devel
Summary:        Development files for libgnome
Group:          Development/Libraries/GNOME
#FIXME: major bloat, should be only
#Requires: libbonobo-devel
#
Requires:       %{name} = %{version}
Requires:       audiofile-devel
Requires:       gconf2-devel
Requires:       glib2-devel
Requires:       glibc-devel
Requires:       gnome-vfs2-devel
Requires:       libbonobo-devel
Requires:       orbit2-devel
Requires:       popt-devel
Provides:       libgnome-doc = %{version}
Obsoletes:      libgnome-doc < %{version}
#

%description devel
This subpackage contains the header files for developing
applications that want to make use of libgnome.

%lang_package

%prep
%setup -q
translation-update-upstream
%patch4
%patch6
%patch8 -p1
# Needs rebase
#patch9 -p1

%build
NOCONFIGURE=1 ./autogen.sh
%configure \
	--disable-esd \
	--enable-gtk-doc \
	--disable-static \
	%{nil}
make %{?_smp_mflags}

%install
%make_install
mkdir -p %{buildroot}/%{_datadir}/gnome/help %{buildroot}/%{_datadir}/gnome/autostart
%find_lang %{name}-2.0
%find_gconf_schemas
cat %{name}.schemas_list >%{name}.lst
find %{buildroot} -type f -name "*.la" -delete -print
%fdupes %{buildroot}/%{_prefix}

%pre -f %{name}.schemas_pre
%post -p /sbin/ldconfig
%posttrans -f %{name}.schemas_posttrans
%preun -f %{name}.schemas_preun
%postun -p /sbin/ldconfig

%files -f %{name}.lst
%license COPYING.LIB
%doc AUTHORS NEWS README
%{_bindir}/*
%dir %{_datadir}/gnome
# generic directory for help files
%dir %{_datadir}/gnome/help
# generic directory for autostart desktop files
# NOTE: This directory is referenced by (and technically belongs to)
# gnome-session. But libgnome provides complete support for such
# binaries so these binaries don't need gnome-session.
%dir %{_datadir}/gnome/autostart
%{_datadir}/gnome-background-properties/*.xml
%{_datadir}/pixmaps/backgrounds/gnome/*.*
%{_libdir}/*.*so.*
%{_libdir}/bonobo/monikers/*.so
%{_libdir}/bonobo/servers/*
%{_mandir}/man7/gnome-options.7%{ext_man}
# generic directory for sound events
%dir %{_sysconfdir}/sound
%dir %{_sysconfdir}/sound/events
%config %{_sysconfdir}/sound/events/*.soundlist
# own directory to break build loop libgnome->gnome-themes->librsvg->libgnomeprintui->...->libgnome:
%dir %{_datadir}/gnome-background-properties
%dir %{_datadir}/pixmaps/backgrounds
%dir %{_datadir}/pixmaps/backgrounds/gnome

%files lang -f %{name}-2.0.lang

%files devel
%{_includedir}/libgnome-2.0
%{_libdir}/*.so
%{_libdir}/pkgconfig/libgnome-2.0.pc
%{_datadir}/gtk-doc/html/libgnome

%changelog
* Tue Mar 20 2018 dimstar@opensuse.org
- Unconditionally enable translation-update-upstream: on
  Tumbleweed, this results in a NOP and for Leap in SLE paid
  translations being used (boo#1086036).
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Tue Feb  6 2018 dimstar@opensuse.org
- Update to version 2.32.2+20170910.8487c2b4:
  + Updatad translations.
* Tue Sep 26 2017 zaitor@opensuse.org
- Drop forgotten and obsolete libesd-devel Requires in devel
  sub-package, we already pass --disable-esd to configure.
* Fri Sep  8 2017 jengelh@inai.de
- Update RPM groups, old boilerplate summaries and old
  macros/constructs. fdupes must not run across hardlink locations.
* Tue Aug 15 2017 zaitor@opensuse.org
- Update to version 2.32.2+20170807.33313713:
  + Fix compiler warnings.
  + Add DOAP file.
  + Don't use G_DISABLE_DEPRECATED.
  + doap category deprecated.
  + gnome-config.h: Fix invalid UTF-8 in header.
  + Updated translations.
- Switch to git-checkout via source service.
- Pass NOCONFIGURE=1 ./autogen.sh instead of gtkdocize and
  autoreconf, we need to bootstrap now that we are using
  gitcheckout.
- Disable libgnome-help-bundles.patch: Needs rebase.
- Conditionally apply translations-update-upstream BuildRequires
  and macro for non-openSUSE only.
* Mon Apr 15 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Fri Mar 22 2013 cfarrell@suse.com
- license update: LGPL-2.1+
  No evidence of GPL-2.0+ in the package
* Thu Mar  7 2013 dimstar@opensuse.org
- Add "#undef G_DISABLE_DEPRECATED" to the generated config.h, to
  allow the usage of deprectaed glib symbols (e.g. g_thread_*).
* Mon Jul 23 2012 dimstar@opensuse.org
- Recommend yelp: a bunch of legacy apps using gconf to find the
  right help interpreter rely on /usr/bin/gnome-help, which comes
  from yelp (as a symlink to susehelp). As it can be reconfigured
  in gconf we do not hard require yelp, but recommend it.
* Wed May  4 2011 vuntz@opensuse.org
- Update to version 2.32.1:
  + Updated translations.
* Mon Sep 27 2010 vuntz@opensuse.org
- Update to version 2.32.0:
  + Updated translations.
* Tue Aug 31 2010 aj@suse.de
- Recommend instead of require lang package since it's not mandatory.
* Thu Jul  8 2010 dimstar@opensuse.org
- Update to version 2.31.0:
  + gnome-sound APIs now use libcanberra internally. That means
    that gnome_sound_connection_get() will always return error
    (-1), and gnome_sound_sample_load also always return -1 but
    still cache the sample using the libcanberra API.
  + libgnome continues to link to libesound and libaudiofile for
    ABI compatibility; use --disable-esd to remove this dependency.
    (bgo#603198, bgo#603349)
- do no longer depend on esd by passing --disable-esd to configure.
- Remove libesd-devel BuildRequires, add libcanberra-devel.
* Sat Apr 24 2010 coolo@novell.com
- buildrequire pkg-config to fix provides
* Tue Mar 30 2010 vuntz@opensuse.org
- Update to version 2.30.0:
  + Enable silent build using AM_SILENT_RULES
  + Put SlowKeys and BounceKeys default delays back to 300
  + Deprecate gnome-sound
  + Deprecate gnome_[un]setenv
  + Update the description of the picture_options key
  + Updated translations.
- Remove en@shaw translations on 11.2 and earlier.
* Thu Dec 17 2009 jengelh@medozas.de
- Add baselibs.conf as a source
* Wed Sep 23 2009 dimstar@opensuse.org
- Update to version 2.28.0:
  + Updated translations.
* Sat Aug  1 2009 captain.magnus@opensuse.org
- Update to version 2.27.5:
  + Update default properties for menus_have_icons,
    buttons_have_icons and toolbar_style
  + Port gnome-sound.c to g_poll to fix portability for old OSX
    versions without poll.
  + Update the address of the FSF by replacing old bits with new
    ones
  + Translation updates
* Tue Mar 17 2009 vuntz@novell.com
- Update to version 2.26.0:
  + Updated translations.
- Remove AutoReqProv: it's default now.
- Remove -fno-strict-aliasing from CFLAGS.
- Use makeinstall
- Merge doc package in devel package since it only contain gtk-doc
  files.
- Call gtkdocize --copy before autoreconf: it seems the gtk-doc
  used to create tarball doesn't play well with the gtk-doc we have
  in the distribution at the moment.
* Mon Mar 16 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Fri Mar  6 2009 vuntz@novell.com
- Update to version 2.25.1:
  + Fix warnings about missing format specifiers
  + Remove #if 0'ed out code
  + Updated translations
- Drop libgnome-pixmaps.patch: this is a really old patch that
  shouldn't be needed.
- Drop libgnome-sentinel.patch: upstream rejected it because it's
  not 100%% correct.
* Sat Jan 17 2009 crrodriguez@suse.de
- remove "la" files, baby step to clean up all references
  to libavahi-*.la
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Tue Sep 23 2008 maw@suse.de
- Update to version 2.24.1:
  + Make thumbnail housekeeping less aggressive
  + Updated translations.
* Sun Sep 21 2008 mboman@suse.de
- Update to version 2.23.92:
  + Port gnome-open to GIO.
  + Build fix
* Thu Aug 28 2008 maw@suse.de
- Update to version 2.23.5:
  + Fix sound related issues; as a result, drop
    libgnome-sound-409884.patch (bnc#409884).
* Tue Aug  5 2008 rodrigo@suse.de
- Added upstream patch for sound hangs with PA (bnc#409884)
* Fri Jul 18 2008 rodrigo@suse.de
- Tag and upstream patches
* Wed Jun 18 2008 maw@suse.de
- Update to version 2.23.4:
  + Add schema to support the thumbnail cache cleaner
  + Add disable_application_handlers lockdown schema
  + Misc. improvements.
* Mon Jun  9 2008 maw@suse.de
- Update to version 2.23.3:
  + Code cleanups
  + Added schema to support the thumbnail cache cleaner
  + Leak fix
  + Add disable_application_handlers lockdown schema.
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Fri Mar 14 2008 maw@suse.de
- Update to version 2.22.0:
  + Add tasks and calendar schemas
  + Use the GIO backend for the filechooser.
* Thu Mar 13 2008 sbrabec@suse.cz
- Custom look'n'feel gconf keys moved to gconf2-branding-openSUSE
  (fate#301474).
* Thu Jan 31 2008 maw@suse.de
- Update to version 2.21.90:
  + Set sound as enabled by default
  + Bypass a11y on win32
  + Remove unused popt stuff
  + Fix the toolbar icon size schema type (bnc#401030)
  + Win32 fixes
  + SElinux fixes
  + Warning fixes
  + Updated translations.
* Fri Nov 23 2007 maw@suse.de
- Update to version 2.20.1.1:
  + Updated translations.
* Wed Sep 26 2007 sbrabec@suse.cz
- Do not patch autogenerated file (#328562).
* Mon Sep 17 2007 sbrabec@suse.cz
- Updated to version 2.20.0:
  * Build fixes
  * Set new background
  * Fix module loading
  * Only depend on esd when esd is compiled in
  * Updated translations
* Fri Sep 14 2007 hpj@suse.de
- Update libgnome-help-bundles.patch to handle more cases.
* Fri Sep 14 2007 hpj@suse.de
- Add libgnome-help-bundles.patch to make apps able to locate help
  files that live in help-bundle/ instead of help/.
* Fri Aug 24 2007 cgaisford@novell.com
- updated the libgnome-preconf.dif file to disable accessibility
  by default.  This is in reference to Novell Bug #302316.
* Tue Aug  7 2007 maw@suse.de
- Use %%fdupes
- Split off a -lang subpackage
- s#%%run_ldconfig#/sbin/ldconfig/ in %%post and %%postun.
* Tue Jul 31 2007 maw@suse.de
- Update to version 2.19.1:
  * Don't initialise ALSA when sound is disabled (449249; Christian Persch)
  * Translation updates: Runa Bhattacharjee (bn_IN), Hendrik Richter (de),
  Iñaki Larrañaga Murgoitio (eu), Ilkka Tuohela (fi), Ankit Patel (gu),
  Takeshi AIHANA (ja), Leonardo Fereira Fontenelle (pt_BR), Clytie Siddall (vi).
* Thu Jul  5 2007 maw@suse.de
- Update to version 2.19.0
  * Rebuild the type builtins when the Makefile changes (Christian Persch)
  * Make bug-buddy work with applets again (Matthias Clasen, #424949)
  * Fix problems when building static libraries (Kjartan Maraas, #405352)
  * Fix typos (Kenneth Nielsen, Kjartan Maraas, #429751)
  * Add more information to docs for gnome_program_init () (Christian Persch,
  [#82943])
  * Updated translations
- mg: Thierry Randrianiriana
- nb: Kjartan Maraas
- sv: Daniel Nylander
- cy: Rhys Jones
- ar: Kjartan Maraas
- th: Theppitak Karoonboonyanan
- eu: Inaki Larranaga Murgoitio
- et: Priit Laes
- ca: Josep Puigdemont i Casamaj�
- gl: Ignacio Casal Quinteiro
- or: Subhransu Behera
- en_GB: David Lodge
- he: Yair Hershkovitz
* Mon Apr 16 2007 sbrabec@suse.cz
- Do not patch autogenerated files. Fixes default theme and default
  soundlist.
* Wed Mar 21 2007 maw@suse.de
- Update to version 2.18.0
- Duplicated #includes removed from several files
- Update to the MAINTAINERS file.
* Tue Feb 27 2007 sbrabec@suse.cz
- Reduced BuildRequires.
* Fri Feb 16 2007 maw@suse.de
- Update to version 2.17.91
* Tue Feb 13 2007 sbrabec@suse.cz
- Do not build unusable static libraries (#238552#c17).
* Fri Feb  9 2007 sbrabec@suse.cz
- Own %%{_datadir}/gnome/autostart.
* Sat Jan  6 2007 sbrabec@suse.cz
- Added %%{_sysconfdir}/sound to file list.
* Thu Dec 14 2006 sbrabec@suse.cz
- Added %%{_datadir}/gnome/help to file list.
* Wed Dec 13 2006 maw@suse.de
- Nuke second, redundant %%postun.
* Wed Dec 13 2006 sbrabec@suse.cz
- Prefix changed to /usr.
- Spec file cleanup.
* Sat Sep 30 2006 olh@suse.de
- use some portable way to clear a va_list
- build with make -j (#199805)
* Mon Sep 18 2006 jhargadon@suse.de
- reapplied libgnome_preconf.dif which was mistakenly removed.
* Wed Sep 13 2006 jhargadon@suse.de
- update to version 2.16.0
- Fix a small leak in a moniker.
- Revert the theme name again
- New and updated translations
* Thu Aug 17 2006 jhargadon@suse.de
- update to version 2.15.2
- Use the right gtk+ theme name in the schema.
- updated translations
* Fri Jul 21 2006 gekker@suse.de
- Update to version 2.15.1
- Remove upstreamed patches
  * Bug fixes:
  - Cleanups and related (Kjartan, Christian Persch)
  - Win32 portability (Tor)
  - Input method gconf schema defaults adjusted for Gtk+ 2.9.x
    (Christian)
  - API docs updates (Kjartan, Christian, Kristof Vansant)
  - po/LINGUAS handling (Przemysaw Grzegorczyk)
  - Constify some data (Beno� Dejean)
  * New and updated translations.
- update to libgnome 2.14.1
  * Bug fixes:
  - Fix memory leaks in gnome-program (Christian Persch)
  - Fixes for locating help files (Stefan Kost, Christian Persch)
  - Add --enable-esd switch (Leonardo Boshell)
  - Fix --espeaker option (Michael H. Schimek)
  - General cleanups (Kjartan)
  - Fix for 'run in terminal' launchers with gnome-terminal as
    the preferred terminal. (Vincent Vuntz)
  * Updated and new translations.
- update to libgnome 2.14.0
  * Updated and new translations.
- update to libgnome 2.13.90
  * Bug fixes
  - Initialize all the members of GnomeModuleInfo
    (Christian Perch)
  - Use GOption instead of popt as default (Christian Perch)
  - Add handling of GNOME_VFS_ERROR_INVALID_URI
    (Claudio Saavedra)
- update to libgnome 2.13.7
  * Bug fixes
  - Fix compilation issues due to the missing inclusion
    of popt.h (Emmanuele Bassi)
- update to libgnome 2.13.6
  * Bug fixes
  - Make popt usage deprecated and move to a full GOption
    support (Christian)
- update to libgnome 2.13.5
  * Bug fixes
  - Fix leaks in GOption code (Christian)
  - Don't make toolbars detachable by default (Sebastien)
  - Build related cleanups (Mark, Kjartan)
  * Docs
  - Improve docs for GOption handling in GnomeProgram
  * Translations
- update to libgnome 2.13.4
  * Bug fixes
  - Fix the broken fix for GnomeProgram. (Gustavo)
    (It broke gnome-python)
- update to libgnome 2.13.3
  * Bug fixes
  - Give feedback from gnome-url if the host can't be found
    (Christian Neumair)
  - Fix some warnings (Kjartan)
  * Translations
- update to libgnome 2.13.2
  * Features
  - New show_input_method_menu gconf key (Matthias Clasen)
  - Update of the cursors descriptions for the new GTK (Sebastien Bacher)
  - New remember_numlock_state gconf key (Jrg Billeter)
  - Add GNOME_URL_ERROR_CANCELLED and return it
    in gnome_url_show_with_env (Christian Neumair)
  * Bug fixes
  - Use G_SEARCHPATH_SEPARATOR_S instead of hardcoded ":"(Tor Lillqvist)
  - Add support for GOption argument parsing (Pawel Sliwowski, chpe) [#307312]
  - Use gnome-vfs on Win32, too (Tor Lillqvist)
  * Translation updates.
* Fri Jun  9 2006 sreeves@suse.de
- Fix for 165711 - new "siren" sound
* Wed May 31 2006 jpr@suse.de
- Make the wallpaper for nld9 upgrades the correct file (#177859)
* Sun Mar  5 2006 dobey@suse.de
- Switch default theme to Gilouche
* Thu Feb 23 2006 mfabian@suse.de
- Bugzilla #54176: remove libgnome-default-monospace-font.diff,
  the upstream default "monospace" guarantees an acceptable
  result for the language set in the locale environment.
  Using "Bitstream Vera Sans Mono" as the default monospace font
  cause problems for example for Greek because the fallback
  glyphs used for Greek don't look nice together with
  "Bitstream Vera Sans Mono".
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 17 2006 dobey@suse.de
- Default to new Chlorophyll theme
* Tue Jan 10 2006 ro@suse.de
- create empty va_list instead of using NULL (not portable)
* Thu Nov 24 2005 meissner@suse.de
- mark gnome_program_init() with sentinel.
* Tue Sep 13 2005 sbrabec@suse.cz
- Require libgnome by libgnome-devel (#116768).
* Wed Sep  7 2005 sbrabec@suse.cz
- Updated to version 2.12.0.1.
* Tue Sep  6 2005 sbrabec@suse.cz
- Updated to version 2.12.0.
* Fri Sep  2 2005 jpr@suse.de
- Update patch so we have sounds by default (114726)
* Tue Aug 23 2005 gekker@suse.de
- Update to version 2.11.3
* Sat Aug 13 2005 aj@suse.de
- Fix last patch to build on all archs.
* Thu Aug 11 2005 gekker@suse.de
- Update to version 2.11.2
- Fix use of uninitialized variable
* Thu Aug  4 2005 gekker@suse.de
- Fix default sound patch to still work after autoreconf (74355).
* Thu Jul 21 2005 gekker@suse.de
- Update to version 2.11.1
* Fri Jun 24 2005 sbrabec@suse.cz
- Fixed devel requirements (#8283).
- Removed unneeded static modules and .la files for modules.
* Wed Jun  1 2005 sbrabec@suse.cz
- Fixed devel requirements (#72282).
* Thu Apr 14 2005 sbrabec@suse.cz
- Added audiofile-devel to neededforbuild.
* Mon Apr 11 2005 sbrabec@suse.cz
- Fixed Requires of doc subpackage.
* Mon Apr  4 2005 sbrabec@suse.cz
- Fixed incomplete array element type.
* Tue Mar  8 2005 gekker@suse.de
- Update to version 2.10.0 (GNOME 2.10).
* Mon Mar  7 2005 clahey@suse.de
- Apply all settings to both schemas and schemas.in.
* Fri Mar  4 2005 gekker@suse.de
- Add libgnome-default-monospace-font.diff (54176).
* Wed Mar  2 2005 gekker@suse.de
- update to 2.9.2
* Mon Feb  7 2005 ro@suse.de
- added mDNSResponder to neededforbuild
* Thu Jan 27 2005 hhetter@suse.de
- updated to version 2.9.1
- force gtk-doc generation
* Mon Nov 22 2004 gekker@suse.de
- Update to version 2.8.0
* Fri Nov 19 2004 ro@suse.de
- removed extra aclocal include directive
* Mon Oct 25 2004 ro@suse.de
- locale rename: no -> nb
* Tue Oct 12 2004 sbrabec@suse.cz
- Use gnutls instead of openssl (#44438).
* Tue Sep  7 2004 shprasad@suse.de
- Fixes bug #64555 (Fix given by sdharmaveer@novell.com)
  Makes GNOME login/logout sounds play by default.
* Mon Aug 23 2004 joeshaw@suse.de
- Set new background image.  (Ximian #62887)
* Wed Jul 14 2004 clahey@suse.de
- Set new background image.
* Wed Jun  2 2004 clahey@suse.de
- Switched to industrial theme and icon theme.  Set background image.
* Mon Apr 26 2004 sbrabec@suse.cz
- Updated to version 2.6.1 (GNOME 2.6).
* Wed Mar 10 2004 hhetter@suse.de
- default gtk theme to Industrial
- default Icon Theme to Gnome Crystal
* Wed Mar 10 2004 sbrabec@suse.cz
- Fixed gconf schemas installation (#33114).
* Wed Feb 25 2004 hhetter@suse.de
- apply patch: libgnome-default-handlers.patch
  default url handler shall be epiphany, not mozilla,
  and don't use netscape-remote
* Thu Feb 12 2004 hhetter@suse.de
- gconf schema (de-)installation in %%post and %%postun
* Sat Jan 10 2004 adrian@suse.de
- add %%run_ldconfig
* Wed Oct 22 2003 sbrabec@suse.cz
- Fixed schemas installation.
* Tue Oct  7 2003 sbrabec@suse.cz
- Updated to version 2.4.0 (GNOME 2.4).
* Mon Aug 18 2003 sbrabec@suse.cz
- Updated to version 2.2.3.
* Mon Jul 14 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Fri Jun 27 2003 sbrabec@suse.cz
- Set localstatedir to /var (needed for gnome-scores).
* Tue Jun 24 2003 sbrabec@suse.cz
- Updated to version 2.2.2.
- Prefix clash fix (gtk-doc).
* Tue May 27 2003 ro@suse.de
- keep buildroot clean
* Mon May 26 2003 sbrabec@suse.cz
- Do not provide gnvfs/gnvfsd (needed by new RPM).
* Wed May 14 2003 sbrabec@suse.cz
- Sync -devel Requires with pkgconfig (bug #26875).
* Wed Apr 30 2003 sf@suse.de
- use autoreconf for libtool working correctly
  (needed patch in Makefile.am)
* Tue Feb 18 2003 hhetter@suse.de
- remove printf in pixmaps.dif
* Thu Feb 13 2003 hhetter@suse.de
- look also in GNOME2_PATH without attr_rel addition, to be
  able to specify exact paths for pixmaps
* Wed Jan 29 2003 hhetter@suse.de
- fix schema list
- updated to version 2.2.0.1
* Wed Jan 15 2003 hhetter@suse.de
- updated to version 2.1.90
- recheck schema list
* Thu Nov 28 2002 hhetter@suse.de
- updated to version 2.0.6 [GNOME 2.0.3]
* Tue Nov  5 2002 sbrabec@suse.cz
- Updated %%files.
- Fixed --libexecdir for biarch.
* Thu Oct 31 2002 hhetter@suse.de
- updated to version 2.0.5
* Tue Sep 24 2002 sbrabec@suse.cz
- Added alsa-devel to neededforbuild, because esound-devel can require it.
- Updated %%files section.
* Fri Sep 20 2002 sbrabec@suse.cz
- Added alsa to neededforbuild, because esound can depend on it.
* Tue Aug 20 2002 hhetter@suse.de
- added PreReq: filesystem
* Thu Aug 15 2002 hhetter@suse.de
- branch doc package
* Wed Aug 14 2002 hhetter@suse.de
- reduce dependencies
* Fri Aug  9 2002 hhetter@suse.de
- add openssl to neededforbuild
* Wed Aug  7 2002 hhetter@suse.de
- updated to version 2.0.2
  * libexec movement
- fix filelist
* Fri Jul 26 2002 adrian@suse.de
- fix neededforbuild
* Tue Jun 25 2002 hhetter@suse.de
- fix schema-list
* Thu Jun 20 2002 hhetter@suse.de
- don't install schemas while make install
* Thu Jun 20 2002 hhetter@suse.de
- supply schema files
* Tue Jun 11 2002 hhetter@suse.de
- updated to version 2.0.1
* Mon Jun 10 2002 hhetter@suse.de
- updated to version 2.0.0
* Tue Jun  4 2002 hhetter@suse.de
- updated to release 1.117.2
* Wed May 15 2002 ro@suse.de
- use libdir
* Wed Apr 10 2002 hhetter@suse.de
- update to 1.114.0 [gnome desktop beta3]
* Fri Feb  1 2002 hhetter@suse.de
- updated to 1.110.0 [gnome desktop alpha2]
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Thu Jan 17 2002 hhetter@suse.de
- prefix to /opt/gnome2
* Mon Jan 14 2002 hhetter@suse.de
- updated to version 1.109.0
  * gconf2-schema updates
  * documentation updates
* Wed Jan  9 2002 hhetter@suse.de
- initial SuSE package for GNOME 2.0 platform
